Struct PaymentHash
pub struct PaymentHash(pub [u8; 32]);Expand description
The payment hash is the hash of the PaymentPreimage which is the value used to lock funds
in HTLCs while they transit the lightning network.
This is not exported to bindings users as we just use [u8; 32] directly
Tuple Fields
0: [u8; 32]Trait Implementations
impl Borrow<[u8]> for PaymentHash
impl Borrow<[u8]> for PaymentHash
impl Clone for PaymentHash
impl Clone for PaymentHash
fn clone(&self) -> PaymentHash
fn clone(&self) -> PaymentHash
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for PaymentHash
impl Debug for PaymentHash
impl Display for PaymentHash
impl Display for PaymentHash
impl From<PaymentPreimage> for PaymentHash
Converts a PaymentPreimage into a PaymentHash by hashing the preimage with SHA256.
impl From<PaymentPreimage> for PaymentHash
Converts a PaymentPreimage into a PaymentHash by hashing the preimage with SHA256.
fn from(value: PaymentPreimage) -> PaymentHash
fn from(value: PaymentPreimage) -> PaymentHash
Converts to this type from the input type.
impl Hash for PaymentHash
impl Hash for PaymentHash
impl LowerHex for PaymentHash
impl LowerHex for PaymentHash
impl Ord for PaymentHash
impl Ord for PaymentHash
impl PartialEq for PaymentHash
impl PartialEq for PaymentHash
impl PartialOrd for PaymentHash
impl PartialOrd for PaymentHash
impl Readable for PaymentHash
impl Readable for PaymentHash
fn read<R>(r: &mut R) -> Result<PaymentHash, DecodeError>where
R: Read,
fn read<R>(r: &mut R) -> Result<PaymentHash, DecodeError>where
R: Read,
Reads a
Self in from the given Read.impl UpperHex for PaymentHash
impl UpperHex for PaymentHash
impl Verification for PaymentHash
impl Verification for PaymentHash
fn hmac_for_offer_payment(
&self,
nonce: Nonce,
expanded_key: &ExpandedKey,
) -> Hmac<Hash>
fn hmac_for_offer_payment( &self, nonce: Nonce, expanded_key: &ExpandedKey, ) -> Hmac<Hash>
Constructs an HMAC to include in OffersContext::InboundPayment for the payment hash
along with the given Nonce.
fn verify_for_offer_payment(
&self,
hmac: Hmac<Hash>,
nonce: Nonce,
expanded_key: &ExpandedKey,
) -> Result<(), ()>
fn verify_for_offer_payment( &self, hmac: Hmac<Hash>, nonce: Nonce, expanded_key: &ExpandedKey, ) -> Result<(), ()>
Authenticates the payment id using an HMAC and a Nonce taken from an
OffersContext::InboundPayment.
impl Writeable for PaymentHash
impl Writeable for PaymentHash
impl Copy for PaymentHash
impl Eq for PaymentHash
impl StructuralPartialEq for PaymentHash